CREATE DATABASE 'RujelStatic' DEFAULT CHARACTER SET utf8;

CREATE TABLE SCHEMA_VERSION (
  MODEL_NAME varchar(255),
  VERSION_NUMBER smallint unsigned NOT NULL,
  VERSION_TITLE varchar(255),
  INSTALL_DATE timestamp
);

INSERT INTO SCHEMA_VERSION (MODEL_NAME,VERSION_NUMBER,VERSION_TITLE)
  VALUES ('EduPlanModel',1,'0.9'),('EduResults',2,'0.9.5');

CREATE TABLE BASE_EDU_CYCLE (
  C_ID smallint NOT NULL,
  GRADE_NUM smallint,
  SUBJECT_NAME varchar(28),
  SUB_GROUPS smallint NOT NULL,
  PRIMARY KEY (C_ID)
);

CREATE TABLE BASE_ENTITYS (
  E_ID smallint NOT NULL,
  ENTITY_NAME varchar(28) NOT NULL,
  SQL_TABLE varchar(255),
  PRIMARY KEY (E_ID)
);

CREATE TABLE BASE_ST_TEXT_STORE (
  T_ID int NOT NULL,
  FROM_ENTITY smallint NOT NULL,
  STORED_TEXT BLOB SUB_TYPE TEXT NOT NULL,
  PRIMARY KEY (T_ID)
);

CREATE TABLE ITOG_COMMENT (
  ITOG_CONTAINER smallint NOT NULL,
  EDU_CYCLE int NOT NULL,
  STUDENT_ID int NOT NULL,
  COMMENT_TEXT BLOB SUB_TYPE TEXT NOT NULL,
  PRIMARY KEY (ITOG_CONTAINER,EDU_CYCLE,STUDENT_ID)
);

CREATE TABLE ITOG_CONTAINER (
  I_ID smallint NOT NULL,
  ITOG_TYPE smallint NOT NULL,
  ORDER_NUM smallint,
  EDU_YEAR smallint NOT NULL,
  PRIMARY KEY (I_ID)
);

CREATE TABLE ITOG_MARK (
  ITOG_CONTAINER smallint NOT NULL,
  EDU_CYCLE smallint NOT NULL,
  STUDENT_ID int NOT NULL,
  MARK_TITLE varchar(5) NOT NULL,
  SUCCESS_VALUE decimal(5,4),
  ITOG_FLAGS smallint NOT NULL,
  PRIMARY KEY (ITOG_CONTAINER,EDU_CYCLE,STUDENT_ID)
);

CREATE TABLE ITOG_TYPE (
  T_ID smallint NOT NULL,
  SHORT_TITLE varchar(5),
  TYPE_NAME varchar(28),
  IN_YEAR_COUNT smallint NOT NULL,
  SORT_NUM smallint NOT NULL,
  PRIMARY KEY (T_ID)
);

CREATE TABLE ITOG_TYPE_LIST (
  TL_ID int NOT NULL,
  LIST_NAME varchar(28) NOT NULL,
  ITOG_TYPE smallint NOT NULL,
  MARK_INDEX smallint,
  PRIMARY KEY (TL_ID)
);

CREATE TABLE PL_CYCLE (
  C_ID smallint NOT NULL,
  GRADE_NUM smallint NOT NULL,
  SUBJECT_ID smallint NOT NULL,
  SCHOOL_NUM smallint NOT NULL,
  EDU_SECTION smallint NOT NULL,
  PRIMARY KEY (C_ID)
);

CREATE TABLE PL_SUBJECT (
  S_ID smallint NOT NULL,
  AREA_ID smallint NOT NULL,
  SORT_NUM smallint NOT NULL,
  SHORT_NAME varchar(28) NOT NULL,
  FULL_NAME varchar(255),
  SUB_GROUPS smallint NOT NULL,
  NORMAL_GROUP smallint NOT NULL,
  SPEC_FLAGS smallint NOT NULL,
  PRIMARY KEY (S_ID)
);

CREATE TABLE PL_SUBJ_AREA (
  A_ID smallint NOT NULL,
  AREA_NAME varchar(28) NOT NULL,
  SORT_NUM smallint NOT NULL,
  PRIMARY KEY (A_ID)
);

CREATE TABLE PRT_ACHIEVEMENT (
  A_ID int NOT NULL,
  EVENT_ID int NOT NULL,
  STUDENT_ID int NOT NULL,
  ACHIEVEMENT_STRING varchar(255) NOT NULL,
  ACH_RANK smallint NOT NULL DEFAULT 0,
  WEB_LINK varchar(255),
  PRIMARY KEY (A_ID)
);

CREATE TABLE PRT_EVENT (
  E_ID int NOT NULL,
  ACTUAL_DATE date NOT NULL,
  EVENT_TITLE varchar(255) NOT NULL,
  EVENT_RANK smallint NOT NULL,
  WEB_LINK varchar(255),
  PRIMARY KEY (E_ID)
);

CREATE TABLE TPL_PLAN (
  P_ID smallint NOT NULL,
  FOR_CYCLE	smallint NOT NULL,
  PLAN_DESCRIPTION varchar(255),
  AUTHOR_TEACHER int,
  PRIMARY KEY (P_ID)
);

CREATE TABLE TPL_THEME (
  T_ID int NOT NULL,
  PLAN_ID smallint NOT NULL,
  ORDER_NUM smallint NOT NULL,
  THEME_STRING varchar(255),
  LESSONS_COUNT smallint NOT NULL,
  PRIMARY KEY (T_ID)
);

CREATE TABLE  EO_PK_TABLE (
  NAME char(40),
  PK int
);

CREATE INDEX itogCommentIdx
  ON ITOG_COMMENT (STUDENT_ID);

CREATE INDEX itogMarkIdx
  ON ITOG_MARK (STUDENT_ID);
